pub struct MockOrganizationBillingApi {
OrganizationBillingApi_expectations: MockOrganizationBillingApi_OrganizationBillingApi,
}Fields
OrganizationBillingApi_expectations: MockOrganizationBillingApi_OrganizationBillingApiImplementations
Sourceimpl MockOrganizationBillingApi
impl MockOrganizationBillingApi
Sourcepub fn checkpoint(&mut self)
pub fn checkpoint(&mut self)
Validate that all current expectations for all methods have been satisfied, and discard them.
Sourcepub fn new() -> Self
pub fn new() -> Self
Create a new mock object with no expectations.
This method will not be generated if the real struct
already has a new method. However, it will be
generated if the struct implements a trait with a new
method. The trait’s new method can still be called
like <MockX as TraitY>::new
Sourceimpl MockOrganizationBillingApi
impl MockOrganizationBillingApi
Sourcepub fn expect_change_plan_subscription_frequency(&mut self) -> &mut Expectation
pub fn expect_change_plan_subscription_frequency(&mut self) -> &mut Expectation
Create an Expectation for mocking the change_plan_subscription_frequency method
Sourcepub fn expect_get_billing(&mut self) -> &mut Expectation
pub fn expect_get_billing(&mut self) -> &mut Expectation
Create an Expectation for mocking the get_billing method
Sourcepub fn expect_get_history(&mut self) -> &mut Expectation
pub fn expect_get_history(&mut self) -> &mut Expectation
Create an Expectation for mocking the get_history method
Sourcepub fn expect_get_invoices(&mut self) -> &mut Expectation
pub fn expect_get_invoices(&mut self) -> &mut Expectation
Create an Expectation for mocking the get_invoices method
Sourcepub fn expect_get_transactions(&mut self) -> &mut Expectation
pub fn expect_get_transactions(&mut self) -> &mut Expectation
Create an Expectation for mocking the get_transactions method
Sourcepub fn expect_setup_business_unit(&mut self) -> &mut Expectation
pub fn expect_setup_business_unit(&mut self) -> &mut Expectation
Create an Expectation for mocking the setup_business_unit method